@@ -1,5 +1,5 @@
 /*  cache.h: directory and file cache.
-    Copyright (C) 2006, 2007, 2008, 2009 Werner Baumann
+    Copyright (C) 2006, 2007, 2008, 2009, 2014 Werner Baumann
 
     This file is part of davfs2.
 
@@ -89,8 +89,6 @@ struct dav_node {
        Last-Modified time (smtime). */
     char *etag;
     /* The media-type as in HTTP-header Content-Type. */
-    char *mime_type;
-    /* A linked list of handles for open files. */
     dav_handle *handles;
     /* Size of the contents of the node.
        Files: Initially set to the value of the content-lenght header. When
@@ -148,17 +146,14 @@ struct dav_node_item {
 /* Returned by dav_statfs(). */
 typedef struct dav_stat dav_stat;
 struct dav_stat {
-    off64_t     blocks;
-    off64_t     bfree;
-    off64_t     bavail;
-    off64_t     files;
-    off64_t     ffree;
+    uint64_t    blocks;
+    uint64_t    bavail;
+    uint64_t    files;
+    uint64_t    ffree;
+    uint64_t    n_nodes;
     off_t       bsize;
     off_t       namelen;
-    time_t      utime;      /* Time when last updated with data from the server.
-                               must When 0 this structure contains fake data,
-                               that not be changed when a file is changed or
-                               deleted. */
+    time_t      utime;
 };
 
 
@@ -199,10 +194,10 @@ dav_init_cache(const dav_args *args, const char *mpoint);
    a local backup file is created. All local copies of files and the necessary
    directories are stored in the permanent cache. A new index file of the
    permanent cache is created.
-   If got_sigterm is 1, dirty files will not be stored back to the server.
+   If *got_sigterm is 1, dirty files will not be stored back to the server.
    Finally it frees all nodes. */
 void
-dav_close_cache(int got_sigterm);
+dav_close_cache(volatile int *got_sigterm);
 
 
 /* Registers the kernel_interface.
@@ -294,23 +289,6 @@ int
 dav_getattr(dav_node *node, uid_t uid);
 
 
-/* Checks whether node exists and uid has permissions. The value of
-   extended attribute name is copied into buf. If its size is greater
-   than size, EOVERFLOW is returned.
-   Permissions:
-   uid must have execute permission for parent and all of its ancestors, as
-   well as read permission for parent. */
-int
-dav_getxattr(dav_node *node, const char *name, char *buf, size_t *size,
-             uid_t uid);
-
-
-/* Returns the list of supported extended attributes. This is just
-   user.mime_type. */
-int
-dav_listxattr(dav_node *node, char *buf, size_t *size, uid_t uid);
-
-
 /* Searches for a node with name name in the directory parent and returns the
    node in nodep.
    Permissions:
