@@ -1,5 +1,5 @@
 /*  dav_fuse.c: interface to the fuse kernel module FUSE_KERNEL_VERSION 7.
-    Copyright (C) 2006, 2007, 2008. 2009 Werner Baumann
+    Copyright (C) 2006, 2007, 2008. 2009, 2014 Werner Baumann
 
     This file is part of davfs2.
 
@@ -900,19 +900,10 @@ fuse_stat(void)
         return sizeof(struct fuse_out_header);
     }
 
-    int nblocks = (buf_size - sizeof(struct fuse_in_header)
-                     - sizeof(struct fuse_write_in) - 4095) / st->bsize;
-    if (nblocks > 1) {
-        out->st.blocks = st->blocks / nblocks;
-        out->st.bfree = st->bfree / nblocks;
-        out->st.bavail = st->bavail / nblocks;
-        out->st.bsize = st->bsize * nblocks;
-    } else {
-        out->st.blocks = st->blocks;
-        out->st.bfree = st->bfree;
-        out->st.bavail = st->bavail;
-        out->st.bsize = st->bsize;
-    }
+    out->st.blocks = st->blocks;
+    out->st.bfree = st->bavail;
+    out->st.bavail = st->bavail;
+    out->st.bsize = st->bsize;
     out->st.files = st->files;
     out->st.ffree = st->ffree;
     out->st.namelen = st->namelen;
