@@ -1,28 +1,25 @@
-/* 
-** Interface to the kernel module.
- */
+/*  kernel_interface.h: interface to fuse and coda kernel mocule.
+    Copyright (C) 2006, 2007, 2008, 2009 Werner Baumann
 
-/*
- *  This file is part of davfs2.
- *
- *  davfs2 is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  davfs2 is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with davfs2; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- */
+    This file is part of davfs2.
+
+    davfs2 is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.
+
+    davfs2 is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with davfs2; if not, write to the Free Software Foundation,
+    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 
-#ifndef _DAV_KERNEL_INTERFACE_H_
-#define _DAV_KERNEL_INTERFACE_H_
+#ifndef DAV_KERNEL_INTERFACE_H
+#define DAV_KERNEL_INTERFACE_H
 
 
 /* Function type definitions */
@@ -75,39 +72,25 @@ typedef void (*dav_run_msgloop_fn)(int device, size_t bufsize, time_t idle_time,
    mode      : Mode of the root node (fuse only).
    return value : 0: the file system has not yet been mounted
                   1: the file system has been mounted successfully. */
-int dav_init_kernel_interface(int *dev, dav_run_msgloop_fn *msg_loop,
-                              void **mdata, char **kernel_fs, size_t *buf_size,
-                              const char *url, const char *mpoint, 
-                              unsigned long int mopts, uid_t owner,
-                              gid_t group, mode_t mode);
+int
+dav_init_kernel_interface(int *dev, dav_run_msgloop_fn *msg_loop, void **mdata,
+                          char **kernel_fs, size_t *buf_size, const char *url,
+                          const char *mpoint, const dav_args *args);
 
 
-/* Message loop for coda kernel module CODA_KERNEL_VERSION 2.
+/* Message loop for coda kernel module CODA_KERNEL_VERSION 3.
    Parameters see dav_run_msgloop_fn(). */
-void dav_coda2_loop(int device, size_t bufsize, time_t idle_time,
-                    dav_is_mounted_fn is_mounted,
-                    volatile int *keep_on_running, int dbg);
-
-
-/* Message loop for coda kernel module CODA_KERNEL_VERSION 2.
-   Parameters see dav_run_msgloop_fn(). */
-void dav_coda3_loop(int device, size_t bufsize, time_t idle_time,
-                    dav_is_mounted_fn is_mounted,
-                    volatile int *keep_on_running, int dbg);
-
-
-/* Message loop for fuse kernel module with major number 5.
-   Parameters see dav_run_msgloop_fn(). */
-void dav_fuse5_loop(int device, size_t bufsize, time_t idle_time,
-                    dav_is_mounted_fn is_mounted,
-                    volatile int *keep_on_running, int dbg);
+void dav_coda_loop(int device, size_t bufsize, time_t idle_time,
+                   dav_is_mounted_fn is_mounted,
+                   volatile int *keep_on_running, int dbg);
 
 
 /* Message loop for fuse kernel module with major number 7.
    Parameters see dav_run_msgloop_fn(). */
-void dav_fuse7_loop(int device, size_t bufsize, time_t idle_time,
-                    dav_is_mounted_fn is_mounted,
-                    volatile int *keep_on_running, int dbg);
+void
+dav_fuse_loop(int device, size_t bufsize, time_t idle_time,
+              dav_is_mounted_fn is_mounted, volatile int *keep_on_running,
+              int dbg);
 
 
-#endif /* _DAV_KERNEL_INTERFACE_H_ */
+#endif /* DAV_KERNEL_INTERFACE_H */
