@@ -1,5 +1,5 @@
 /*  umount_davfs.c: unmount the davfs file system.
-    Copyright (C) 2006, 2007, 2008, 2009 Werner Baumann
+    Copyright (C) 2006, 2007, 2008, 2009, 2014 Werner Baumann
 
     This file is part of davfs2.
 
@@ -72,7 +72,7 @@ main(int argc, char *argv[])
     bindtextdomain(PACKAGE, LOCALEDIR);
     textdomain(PACKAGE);
 
-    char *short_options = "Vhflnrv";
+    char *short_options = "Vhflnrt:v";
     static const struct option options[] = {
         {"version", no_argument, NULL, 'V'},
         {"help", no_argument, NULL, 'h'},
@@ -107,6 +107,7 @@ main(int argc, char *argv[])
         case 'n':
         case 'r':
         case 'v':
+        case 't':
         case '?':
             break;
         default:
