@@ -1,5 +1,5 @@
 /*  webdav.c: send requests to the WebDAV server.
-    Copyright (C) 2006, 2007, 2008, 2009 Werner Baumann
+    Copyright (C) 2006, 2007, 2008, 2009, 2014 Werner Baumann
 
     This file is part of davfs2.
 
@@ -37,6 +37,9 @@
 #ifdef HAVE_LIMITS_H
 #include <limits.h>
 #endif
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
 #include <stdio.h>
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
@@ -99,8 +102,8 @@ typedef struct {
 
 typedef struct {
     int error;
-    off64_t total;              /* Total amount of available bytes. */
-    off64_t used;               /* Used bytes. */
+    uint64_t available;         /* Amount of available bytes (quota - used). */
+    uint64_t used;              /* Used bytes. */
 } quota_context;
 
 
@@ -110,30 +113,41 @@ typedef struct {
 /* Properties to be retrieved from the server. This constants
    are used by dav_get_collection(). */
 enum {
-    ETAG = 0,
+    TYPE = 0,
     LENGTH,
+    ETAG,
     MODIFIED,
-    TYPE,
-    EXECUTE,
-    END
+    EXECUTE
 };
 
-static const ne_propname prop_names[] = {
-    [ETAG] = {"DAV:", "getetag"},
-    [LENGTH] = {"DAV:", "getcontentlength"},
-    [MODIFIED] = {"DAV:", "getlastmodified"},
+static const ne_propname full_prop_names[] = {
     [TYPE] = {"DAV:", "resourcetype"},
+    [LENGTH] = {"DAV:", "getcontentlength"},
+    [ETAG] = {"DAV:", "getetag"},
+    [MODIFIED] = {"DAV:", "getlastmodified"},
     [EXECUTE] = {"http://apache.org/dav/props/", "executable"},
-    [END] = {NULL, NULL}
+    {NULL, NULL}
 };
 
-static const ne_propname anonymous_prop_names[] = {
-    [ETAG] = {NULL, "getetag"},
-    [LENGTH] = {NULL, "getcontentlength"},
-    [MODIFIED] = {NULL, "getlastmodified"},
+static const ne_propname full_anonymous_prop_names[] = {
     [TYPE] = {NULL, "resourcetype"},
+    [LENGTH] = {NULL, "getcontentlength"},
+    [ETAG] = {NULL, "getetag"},
+    [MODIFIED] = {NULL, "getlastmodified"},
     [EXECUTE] = {NULL, "executable"},
-    [END] = {NULL, NULL}
+    {NULL, NULL}
+};
+
+static const ne_propname min_prop_names[] = {
+    [TYPE] = {"DAV:", "resourcetype"},
+    [LENGTH] = {"DAV:", "getcontentlength"},
+    {NULL, NULL}
+};
+
+static const ne_propname min_anonymous_prop_names[] = {
+    [TYPE] = {NULL, "resourcetype"},
+    [LENGTH] = {NULL, "getcontentlength"},
+    {NULL, NULL}
 };
 
 /* Properties to be retrieved from the server. This constants
@@ -204,6 +218,11 @@ static int ignore_dav_header;
 /* Use "Content-Encoding: gzip" for GET requests. */
 static int use_compression;
 
+/* Only request a minimal set of properties. */
+static int min_propset;
+static const ne_propname *prop_names;
+static const ne_propname *anonymous_prop_names;
+
 /* Will be set to 1 when dav_init_connection() succeeded. */
 static int initialized;
 
@@ -305,9 +324,6 @@ prop_result(void *userdata, const ne_uri *uri, const ne_prop_result_set *set);
 static void
 quota_result(void *userdata, const ne_uri *uri, const ne_prop_result_set *set);
 
-static int
-quota_reader(void *userdata, const char *block, size_t length);
-
 static int
 ssl_verify(void *userdata, int failures, const ne_ssl_certificate *cert);
 
@@ -488,6 +504,14 @@ dav_init_webdav(const dav_args *args)
     precheck = args->precheck;
     ignore_dav_header = args->ignore_dav_header;
     use_compression = args->use_compression & ne_has_support(NE_FEATURE_ZLIB);
+    min_propset = args->min_propset;
+    if (min_propset) {
+        prop_names = min_prop_names;
+        anonymous_prop_names = min_anonymous_prop_names;
+    } else {
+        prop_names = full_prop_names;
+        anonymous_prop_names = full_anonymous_prop_names;
+    }
 }
 
 
@@ -1123,7 +1147,7 @@ dav_put(const char *path, const char *cache_path, int *exists, time_t *expire,
 
 
 int
-dav_quota(const char *path, off64_t *total, off64_t *used)
+dav_quota(const char *path, uint64_t *available, uint64_t *used)
 {
     int ret;
     if (!initialized) {
@@ -1132,11 +1156,10 @@ dav_quota(const char *path, off64_t *total, off64_t *used)
     }
 
     static int use_rfc = 1;
-    static int use_userinfo = 1;
 
     quota_context ctx;
     ctx.error = 0;
-    ctx.total = 0;
+    ctx.available = 0;
     ctx.used = 0;
     ret = EIO;
     char *spath = ne_path_escape(path);
@@ -1155,24 +1178,8 @@ dav_quota(const char *path, off64_t *total, off64_t *used)
         }
     }
 
-    if (ret && use_userinfo) {
-        ctx.error = 0;
-        ne_request *req = ne_request_create(session, "USERINFO", spath);
-        ne_add_response_body_reader(req, ne_accept_2xx, quota_reader, &ctx);
-        ret = ne_request_dispatch(req);
-        ret = get_error(ret, "USERINFO", session);
-        ne_request_destroy(req);
-
-        if (!ret) {
-            if (ctx.error)
-                ret = EIO;
-        } else if (ret != EAGAIN) {
-            use_userinfo = 0;
-        }
-    }
-
     if (!ret) {
-        *total = ctx.total;
+        *available = ctx.available;
         *used = ctx.used;
     }
 
@@ -1865,12 +1872,12 @@ prop_result(void *userdata, const ne_uri *uri, const ne_prop_result_set *set)
         }
     }
 
-    if (strstr(result->path, ctx->path) != result->path) {
+    if (strcasestr(result->path, ctx->path) != result->path) {
         dav_delete_props(result);
         return;
     }
 
-    if (strcmp(result->path, ctx->path) == 0) {
+    if (strcasecmp(result->path, ctx->path) == 0) {
         result->name = ne_strdup("");
     } else {
         if (strlen(result->path) < (strlen(ctx->path) + result->is_dir + 1)) {
@@ -1887,11 +1894,6 @@ prop_result(void *userdata, const ne_uri *uri, const ne_prop_result_set *set)
 #endif
     }
 
-    data = ne_propset_value(set, &prop_names[ETAG]);
-    if (!data)
-        data = ne_propset_value(set, &anonymous_prop_names[ETAG]);
-    result->etag = normalize_etag(data);
-
     data = ne_propset_value(set, &prop_names[LENGTH]);
     if (!data)
         data = ne_propset_value(set, &anonymous_prop_names[LENGTH]);
@@ -1902,24 +1904,31 @@ prop_result(void *userdata, const ne_uri *uri, const ne_prop_result_set *set)
          result->size = strtol(data, NULL, 10);
 #endif /* _FILE_OFFSET_BITS != 64 */
 
-    data = ne_propset_value(set, &prop_names[MODIFIED]);
-    if (!data)
-        data = ne_propset_value(set, &anonymous_prop_names[MODIFIED]);
-    if (data) {
-        result->mtime = ne_httpdate_parse(data);
-        if (result->mtime == (time_t) -1)
-            result->mtime = ne_iso8601_parse(data);
-        if (result->mtime == (time_t) -1)
-            result->mtime = 0;
-    }
+    if (!min_propset) {
+        data = ne_propset_value(set, &prop_names[ETAG]);
+        if (!data)
+            data = ne_propset_value(set, &anonymous_prop_names[ETAG]);
+        result->etag = normalize_etag(data);
 
-    data = ne_propset_value(set, &prop_names[EXECUTE]);
-    if (!data)
-        data = ne_propset_value(set, &anonymous_prop_names[EXECUTE]);
-    if (!data) {
-        result->is_exec = -1;
-    } else if (*data == 'T') {
-        result->is_exec = 1;
+        data = ne_propset_value(set, &prop_names[MODIFIED]);
+        if (!data)
+            data = ne_propset_value(set, &anonymous_prop_names[MODIFIED]);
+        if (data) {
+            result->mtime = ne_httpdate_parse(data);
+            if (result->mtime == (time_t) -1)
+                result->mtime = ne_iso8601_parse(data);
+            if (result->mtime == (time_t) -1)
+                result->mtime = 0;
+        }
+
+        data = ne_propset_value(set, &prop_names[EXECUTE]);
+        if (!data)
+            data = ne_propset_value(set, &anonymous_prop_names[EXECUTE]);
+        if (!data) {
+            result->is_exec = -1;
+        } else if (*data == 'T') {
+            result->is_exec = 1;
+        }
     }
 
     result->next = ctx->results;
@@ -1927,36 +1936,6 @@ prop_result(void *userdata, const ne_uri *uri, const ne_prop_result_set *set)
 }
 
 
-static int
-quota_reader(void *userdata, const char *block, size_t length)
-{
-    if (length < 1) return 0;
-    quota_context *ctx = (quota_context *) userdata;
-
-    char *quota = ne_strndup(block, length);
-    if (!quota) {
-        ctx->error = 1;
-        return 0;
-    }
-
-    char *number = strtok(quota, ",");
-    if (number) {
-        ctx->total = strtoull(number, NULL, 10);
-    } else {
-        ctx->error = 1;
-        free(quota);
-        return 0;
-    }
-
-    number = strtok(NULL, ",");
-    if (number)
-        ctx->used = strtoull(number, NULL, 10);
-
-    free(quota);
-    return 0;
-}
-
-
 /* Reads available and used bytes from set and stores them in
    userdata. */
 static void
@@ -1968,7 +1947,7 @@ quota_result(void *userdata, const ne_uri *uri, const ne_prop_result_set *set)
 
     const char *data = ne_propset_value(set, &quota_names[AVAILABLE]);
     if (data) {
-        ctx->total = strtoull(data, NULL, 10);
+        ctx->available = strtoull(data, NULL, 10);
     } else {
         const ne_status *st = ne_propset_status(set, &quota_names[AVAILABLE]);
         if (st && st->klass == 4) {
@@ -1982,8 +1961,6 @@ quota_result(void *userdata, const ne_uri *uri, const ne_prop_result_set *set)
     data = ne_propset_value(set, &quota_names[USED]);
     if (data)
         ctx->used = strtoull(data, NULL, 10);
-
-    ctx->total += ctx->used;
 }
 
 
